@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
 our $DATE = '2015-03-07'; # DATE
-our $VERSION = '0.90'; # VERSION
+our $VERSION = '0.91'; # VERSION
 
 use 5.010;
 use strict;
@@ -86,6 +86,8 @@ $SPEC{get_args_from_config} = {
         args => {},
         subcommand_name => {},
         config_profile => {},
+        meta => {},
+        meta_is_normalized => {},
     },
 };
 sub get_args_from_config {
@@ -98,6 +100,11 @@ sub get_args_from_config {
     my $meta    = $fargs{meta};
     my $found;
 
+    unless ($fargs{meta_is_normalized}) {
+        require Perinci::Sub::Normalize;
+        $meta = Perinci::Sub::Normalize::normalize_function_metadata($meta);
+    }
+
     # put GLOBAL before all other sections
     my @sections = sort {
         ($a eq 'GLOBAL' ? 0:1) <=> ($b eq 'GLOBAL' ? 0:1) ||
@@ -152,7 +159,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 0.90 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-07.
+This document describes version 0.91 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-07.
 
 =head1 FUNCTIONS
 
@@ -169,6 +176,10 @@ Arguments ('*' denotes required arguments):
 
 =item * B<config_profile> => I<any>
 
+=item * B<meta> => I<any>
+
+=item * B<meta_is_normalized> => I<any>
+
 =item * B<subcommand_name> => I<any>
 
 =back
